@@ -50,7 +50,8 @@ def start(config, method):
 	if hasattr(config, 'auth_plugin'):
 		app = AuthMiddleware(app, authuser_class=config.auth_plugin.authuser_class)
 	#TODO: add config attributes to control session initialization (e.g config.session_timeout)
-	app = SessionMiddleware(DiskSessionStore(), app)
+	if config.use_session:
+		app = SessionMiddleware(DiskSessionStore(), app)
 
 	if method == 'cgi':
 		from wsgiref.handlers import CGIHandler
@@ -78,4 +79,7 @@ def run(method=None):
 	if not hasattr(config, 'debug'):
 		config.debug = False
 
+	if not hasattr(config, 'use_session'):
+		config.use_session = False
+
 	start(config, method)
