@@ -20,6 +20,7 @@ template_plugin = template.Cheetah()
 port = 8080
 host = '0.0.0.0'
 debug = False
+use_session = False
 
 #add other variables here. They will be 
 #accessible when you 'import config'
@@ -30,12 +31,8 @@ title = '$projectname'
 """
 
 urls_py = """\
-#urlmap file for $projectname
 from simpleweb import urladd
 
-#All the action in simple web happens in application modules
-#these map a url to a module file. examples are given below:
-
 urladd('/', 'controllers.index')
 #urladd('/blog[/[{id:number}[/]]]', 'blogapplication.main')
 """
